crustimoney.experimental.results

Expiremental result constructors, accessors and predicates. These may get promoted, or changed, or dismissed.

Expiremental result constructors, accessors and predicates.
These may get promoted, or changed, or dismissed.
raw docstring

success->recovered-errorsclj

(success->recovered-errors success)

Returns the recovered errors from a result, as set by the experimental recover combinator parser.

Returns the recovered errors from a result, as set by the
experimental `recover` combinator parser.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries